.. _affiliations:

Affiliated packages
===================

We take the good concept of an *Affiliated package* from the `Astropy`_ project.
An affiliated package is a Python package that is not part of the scikit-hep core package but is related to,
and seen as part of, the Scikit-HEP project and community.

Affiliated packages are being identified and the community is most welcome to get in touch.
A full list of the presently affiliated packages follows, together with a very short description of their goals.
In most cases, the affiliated packages have to do with bridging between different technologies and/or popular packages
from the Python scientific software stack.

List of affiliated packages
---------------------------
* `numpythia <https://github.com/scikit-hep/numpythia>`_: interface between Pythia and NumPy.
* `pyjet <https://github.com/scikit-hep/pyjet>`_: interface between FastJet and NumPy.
* `uproot <https://github.com/scikit-hep/uproot>`_: minimalist ROOT I/O in pure Python and Numpy.
* `root_numpy <https://github.com/scikit-hep/root_numpy>`_: interface between ROOT and NumPy.
* `root_pandas <https://github.com/scikit-hep/root_pandas>`_: module for conveniently loading/saving ROOT files as pandas DataFrames.

.. _Astropy : http://www.astropy.org/
